
USE [master]


PRINT ''
PRINT ''
PRINT '**************************************'
PRINT 'Setup DB Option to Truncate log       '
PRINT '**************************************'
PRINT ''


EXEC sp_dboption 'WaspTrackAsset_Trial', 'trunc. log on chkpt.', 'true'
go

DBCC SHRINKDATABASE (WaspTrackAsset_Trial)
Go

PRINT ''
PRINT ''
print '==================   [WaspTrackAsset_Trial]   ==================='
PRINT ''

USE [WaspTrackAsset_Trial]
GO

PRINT ''
PRINT '**********************************************'
PRINT 'Clearing rogue schema entries if they exist   '
PRINT 'This will give a harmless error in MSDE       '
PRINT '**********************************************'
PRINT ''
IF  EXISTS (select * from INFORMATION_SCHEMA.SCHEMATA WHERE schema_name = N'AssetUser')
BEGIN
	print 'FOUND AssetUser Schema, drop it'
	DROP SCHEMA [AssetUser]
END
GO



IF  EXISTS (select * from INFORMATION_SCHEMA.SCHEMATA WHERE schema_name = N'AssetReader')
BEGIN
	print 'FOUND AssetReader Schema, drop it'
	DROP SCHEMA [AssetReader]
END
GO


PRINT ''
PRINT ''
PRINT '******************************************************************'
PRINT 'Try to figure out if the database is installed on waspdbxxx       '
PRINT '******************************************************************'
PRINT ''

DECLARE @nInstanceName nchar(255)
DECLARE @nIndex int
DECLARE @nWaspInstance int

select @nInstanceName = @@servername 

print @nInstanceName

SELECT @nIndex = CHARINDEX('waspdb', @@servername )
if (@nIndex > 0) 
begin
	SET @nInstanceName = SUBSTRING (@nInstanceName, @nIndex, LEN(@nInstanceName) - @nIndex + 1)
	SET @nWaspInstance = 1
	PRINT 'Yes, Wasp instance'
end
else
begin
	PRINT 'No, NOT wasp instance'
	SET @nWaspInstance = 0
	print @nInstanceName
end





PRINT ''
PRINT ''
PRINT '**************************************'
PRINT 'Create AssetUser, AssetReader Accounts'
PRINT '**************************************'
PRINT ''

if  EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'AssetUser')
BEGIN
	print 'Found AssetUser in syslogins'
END

if  EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetUser' and uid < 16382)
BEGIN
	print 'Found AssetUser < 16382, drop the user'
	exec sp_dropuser N'AssetUser'
END


if NOT EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'AssetUser')
BEGIN
	print 'Not finding AssetUser in syslogins, create it'
	declare @logindb nvarchar(132), @loginlang nvarchar(132) select @logindb = N'master', @loginlang = N'us_english'
	if @logindb is null or NOT EXISTS (SELECT * FROM master.dbo.sysdatabases WHERE NAME = @logindb)
		select @logindb = N'master'
	if @loginlang is null or (NOT EXISTS (SELECT * FROM master.dbo.syslanguages WHERE NAME = @loginlang) and @loginlang <> N'us_english')
		select @loginlang = @@language
	exec sp_addlogin N'AssetUser', Serial#1, @logindb, @loginlang
END


if NOT EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetUser' and uid < 16382)
BEGIN
	print 'Not finding AssetUser < 16382, assign db_ roles'
	EXEC sp_grantdbaccess N'AssetUser', N'AssetUser'

	if (@nWaspInstance > 0)
	BEGIN
		exec sp_addrolemember N'db_backupoperator', N'AssetUser'
	END

	exec sp_addrolemember N'db_datareader', N'AssetUser'

	exec sp_addrolemember N'db_datawriter', N'AssetUser'

	EXEC sp_addsrvrolemember N'AssetUser', 'dbcreator'
END	
GO



if  EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'AssetReader')
BEGIN
	print 'Found AssetReader in syslogins'
END

if  EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetReader' and uid < 16382)
BEGIN
	print 'Found AssetReader < 16382, drop the user'
	exec sp_dropuser N'AssetReader'
END
GO

if NOT EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'AssetReader')
BEGIN
	print 'Not finding AssetReader in syslogins, create it'
	declare @logindb nvarchar(132), @loginlang nvarchar(132) select @logindb = N'master', @loginlang = N'us_english'
	if @logindb is null or NOT EXISTS (SELECT * FROM master.dbo.sysdatabases WHERE NAME = @logindb)
		select @logindb = N'master'
	if @loginlang is null or (NOT EXISTS (SELECT * FROM master.dbo.syslanguages WHERE NAME = @loginlang) and @loginlang <> N'us_english')
		select @loginlang = @@language
	exec sp_addlogin N'AssetReader', ReadOnly@1, @logindb, @loginlang
END
GO

if NOT EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetReader' and uid < 16382)
BEGIN
	print 'Not finding AssetReader < 16382, assign db_ roles'

	EXEC sp_grantdbaccess N'AssetReader', N'AssetReader'

	exec sp_addrolemember N'db_datareader', N'AssetReader'
END
GO


DECLARE @spname varchar(255)
DECLARE @sql varchar(255)

DECLARE SPnames CURSOR FOR
select distinct so.[Name]
FROM sysobjects so
WHERE so.[Type] = 'P' and so.[Name] like 'Sp%'

OPEN SPnames

 
WHILE 1=1
begin
   	FETCH SPnames INTO @spname 
	if (@@FETCH_STATUS <> 0) break

	select @sql = 'grant EXECUTE ON [dbo].[' + @spname +']  TO [AssetReader]'
	exec(@sql)
	PRINT @sql

	select @sql = 'grant EXECUTE ON [dbo].[' + @spname +']  TO [AssetUser]'
	exec(@sql)
	PRINT @sql
end

CLOSE SPnames
DEALLOCATE SPnames
GO


-- **********************************************
-- Call the function to fix up orphaned users just in case
print '----------Fixing Up Orphans'
go
sp_change_users_login 'Update_One', 'AssetUser', 'AssetUser'
go
sp_change_users_login 'Update_One', 'AssetReader', 'AssetReader'
go



-- **********************************************
-- This script refreshes all the views. Always run this after all database changes to views have been made
DECLARE @viewname varchar(255)
DECLARE @sql varchar(255)

DECLARE viewnames CURSOR FOR
select distinct so.[Name]
from sysobjects so
where so.[Type] = 'V' and so.[Name] like 'v%'

OPEN viewnames

print  '----------Refreshing Views' 

WHILE 1=1
begin
            FETCH viewnames INTO @viewname 
            if (@@FETCH_STATUS <> 0) break
            select @sql = 'sp_refreshview '+@viewname
			print @viewname
            exec(@sql)    
end

print '----------Completed Refreshing Views'

CLOSE viewnames
DEALLOCATE viewnames
GO
-- End Refresh Views



PRINT ''
PRINT ''
print '==================   [WaspConfig]   ==================='
PRINT ''

USE [WaspConfig]
GO


PRINT ''
PRINT ''
PRINT '******************************************************************'
PRINT 'Try to figure out if the database is installed on waspdbxxx       '
PRINT '******************************************************************'
PRINT ''

DECLARE @nInstanceName nchar(255)
DECLARE @nIndex int
DECLARE @nWaspInstance int

select @nInstanceName = @@servername 

print @nInstanceName

SELECT @nIndex = CHARINDEX('waspdb', @@servername )
if (@nIndex > 0) 
begin
	SET @nInstanceName = SUBSTRING (@nInstanceName, @nIndex, LEN(@nInstanceName) - @nIndex + 1)
	SET @nWaspInstance = 1
	PRINT 'Yes, Wasp instance'
end
else
begin
	PRINT 'No, NOT wasp instance'
	SET @nWaspInstance = 0
	print @nInstanceName
end



PRINT ''
PRINT ''
PRINT '**************************************'
PRINT 'Create AssetUser, AssetReader Accounts'
PRINT '**************************************'
PRINT ''

IF  EXISTS (select * from INFORMATION_SCHEMA.SCHEMATA WHERE schema_name = N'AssetUser')
BEGIN
	print 'FOUND AssetUser Schema, drop it'
	DROP SCHEMA [AssetUser]
END


if  EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'AssetUser')
BEGIN
	print 'Found AssetUser in syslogins'
END

IF  EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetUser' and uid < 16382)
BEGIN
	print 'Found AssetUser < 16382, drop the user'
	-- if AssetUser account exists in WaspConfig, drop it so we start clean
	exec sp_dropuser N'AssetUser'
END


-- check in the master database to see if there is a login account for AssetUser
IF NOT EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'AssetUser')
BEGIN
	print 'Not finding AssetUser in syslogins, create it'
	declare @logindb nvarchar(132), @loginlang nvarchar(132) select @logindb = N'master', @loginlang = N'us_english'
	if @logindb is null or NOT EXISTS (SELECT * FROM master.dbo.sysdatabases WHERE NAME = @logindb)
		select @logindb = N'master'
	if @loginlang is null or (NOT EXISTS (SELECT * FROM master.dbo.syslanguages WHERE NAME = @loginlang) and @loginlang <> N'us_english')
		select @loginlang = @@language
	exec sp_addlogin N'AssetUser', Serial#1, @logindb, @loginlang
END
ELSE
BEGIN
	-- AssetUser Login already exists in master database
	if  NOT EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetUser' and uid < 16382)
	BEGIN
		print 'Not finding AssetUser < 16382, create user from login'
		CREATE USER AssetUser FOR LOGIN AssetUser 

		print 'assign db_ roles'

		if (@nWaspInstance > 0)
		BEGIN
			exec sp_addrolemember N'db_backupoperator', N'AssetUser'
		END

		exec sp_addrolemember N'db_datareader', N'AssetUser'

		exec sp_addrolemember N'db_datawriter', N'AssetUser'

		EXEC sp_addsrvrolemember N'AssetUser', 'dbcreator'
	END
END


if NOT EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetUser' and uid < 16382)
BEGIN
	print 'Not finding AssetUser < 16382, assign db_ roles'
	EXEC sp_grantdbaccess N'AssetUser', N'AssetUser'

	if (@nWaspInstance > 0)
	BEGIN
		exec sp_addrolemember N'db_backupoperator', N'AssetUser'
	END

	exec sp_addrolemember N'db_datareader', N'AssetUser'

	exec sp_addrolemember N'db_datawriter', N'AssetUser'

	EXEC sp_addsrvrolemember N'AssetUser', 'dbcreator'
END	
GO


IF  EXISTS (select * from INFORMATION_SCHEMA.SCHEMATA WHERE schema_name = N'AssetReader')
BEGIN
	print 'FOUND AssetReader Schema, drop it'
	DROP SCHEMA [AssetReader]
END


if  EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'AssetReader')
BEGIN
	print 'Found AssetReader in syslogins'
END

if  EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetReader' and uid < 16382)
BEGIN
	print 'Found AssetReader < 16382, drop the user'
	exec sp_dropuser N'AssetReader'
END
GO

if NOT EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'AssetReader')
BEGIN
	print 'Not finding AssetReader in syslogins, create it'
	declare @logindb nvarchar(132), @loginlang nvarchar(132) select @logindb = N'master', @loginlang = N'us_english'
	if @logindb is null or NOT EXISTS (SELECT * FROM master.dbo.sysdatabases WHERE NAME = @logindb)
		select @logindb = N'master'
	if @loginlang is null or (NOT EXISTS (SELECT * FROM master.dbo.syslanguages WHERE NAME = @loginlang) and @loginlang <> N'us_english')
		select @loginlang = @@language
	exec sp_addlogin N'AssetReader', ReadOnly@1, @logindb, @loginlang
END
ELSE
BEGIN
	-- AssetReader Login already exists in master database
	if  NOT EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetReader' and uid < 16382)
	BEGIN
		print 'Not finding AssetReader < 16382, create user from login'
		CREATE USER AssetReader FOR LOGIN AssetReader 

		print 'assign db_ roles'
		exec sp_addrolemember N'db_datareader', N'AssetReader'
	END
END
GO

if NOT EXISTS (SELECT * FROM dbo.sysusers WHERE NAME = N'AssetReader' and uid < 16382)
BEGIN
	print 'Not finding AssetReader < 16382, assign db_ roles'
	EXEC sp_grantdbaccess N'AssetReader', N'AssetReader'

	exec sp_addrolemember N'db_datareader', N'AssetReader'
END
GO


DECLARE @spname varchar(255)
DECLARE @sql varchar(255)

DECLARE SPnames CURSOR FOR
select distinct so.[Name]
FROM sysobjects so
WHERE so.[Type] = 'P' and so.[Name] like 'Sp%'

OPEN SPnames

 
WHILE 1=1
begin
   	FETCH SPnames INTO @spname 
	if (@@FETCH_STATUS <> 0) break
	
	select @sql = 'grant EXECUTE ON [dbo].[' + @spname +']  TO [AssetReader]'
	exec(@sql)
	PRINT @sql

	select @sql = 'grant EXECUTE ON [dbo].[' + @spname +']  TO [AssetUser]'
	exec(@sql)
	PRINT @sql
end

CLOSE SPnames
DEALLOCATE SPnames
GO


-- **********************************************
-- Call the function to fix up orphaned users just in case
print '----------Fixing Up Orphans'
go
sp_change_users_login 'Update_One', 'AssetUser', 'AssetUser'
go
sp_change_users_login 'Update_One', 'AssetReader', 'AssetReader'
go



-- **********************************************
-- This script refreshes all the views. Always run this after all database changes to views have been made
DECLARE @viewname varchar(255)
DECLARE @sql varchar(255)

DECLARE viewnames CURSOR FOR
select distinct so.[Name]
from sysobjects so
where so.[Type] = 'V' and so.[Name] like 'v%'

OPEN viewnames

print  '----------Refreshing Views' 

WHILE 1=1
begin
            FETCH viewnames INTO @viewname 
            if (@@FETCH_STATUS <> 0) break
            select @sql = 'sp_refreshview '+@viewname
			print @viewname
            exec(@sql)    
end

print '----------Completed Refreshing Views'

CLOSE viewnames
DEALLOCATE viewnames
GO
-- End Refresh Views